/* This file is part of VoltDB.
 * Copyright (C) 2008-2013 VoltDB Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
#include "ClientConfig.h"
#include "ProcedureCallback.hpp"
namespace voltdb {


class DummyStatusListener : public StatusListener {
public:
    StatusListener *m_listener;
    DummyStatusListener(StatusListener *listener) : m_listener(listener) {}
    bool uncaughtException(
            std::exception exception,
            boost::shared_ptr<voltdb::ProcedureCallback> callback,
            InvocationResponse response) {
        if (m_listener != NULL) {
            return m_listener->uncaughtException(exception, callback, response);
        } else {
            std::cerr << exception.what() << std::endl;
            return false;
        }
    }
    bool connectionLost(std::string hostname, int32_t connectionsLeft) {
        if (m_listener != NULL) {
            bool retval = m_listener->connectionLost(hostname, connectionsLeft);
            return retval;
        } else {
            return false;
        }
    }
    bool backpressure(bool hasBackpressure) {
        if (m_listener != NULL) {
            return m_listener->backpressure(hasBackpressure);
        } else {
            return false;
        }
    }
};

    ClientConfig::ClientConfig(
            std::string username,
            std::string password) :
            m_username(username), m_password(password), m_listener(reinterpret_cast<StatusListener*>(NULL)),
            m_maxOutstandingRequests(3000){

    }
    ClientConfig::ClientConfig(
            std::string username,
            std::string password,
            StatusListener *listener) :
            m_username(username), m_password(password), m_listener(new DummyStatusListener(listener)),
            m_maxOutstandingRequests(3000){

    }
    ClientConfig::ClientConfig(
            std::string username,
            std::string password,
            boost::shared_ptr<StatusListener> listener) :
                m_username(username), m_password(password), m_listener(listener),
                m_maxOutstandingRequests(3000) {
    }
}

